@@ -522,23 +522,32 @@ def get_contrib_summary_df(contrib_df, model_output="raw", round=2):
     :param round: rounding of contribution
     """
     contrib_summary_df = pd.DataFrame(columns=['Reason', 'Effect'])
+    
 
     for _, row in contrib_df.iterrows():
         if row['col'] == 'base_value':
-            reason = 'BASE VALUE'
+            reason = 'Average of population'
+            effect = ""
         else:
             reason = f"{row['col']} = {row['value']}"
-        effect = f"{'+' if row['contribution'] >= 0 else ''}"
+            effect = f"{'+' if row['contribution'] >= 0 else ''}"
         if model_output == "probability":
             effect += str(np.round(100*row['contribution'], round))+'%'
         else:
             effect +=  str(np.round(row['contribution'], round))
 
+
         contrib_summary_df = contrib_summary_df.append(
-            pd.DataFrame({
-                'Reason': [reason],
-                'Effect': [effect]
-            }))
+            dict(Reason=reason, Effect=effect), ignore_index=True)
+    
+    if model_output == "probability":
+        final_pred = str(np.round(100*contrib_df.contribution.sum(), round))+'%'
+    else:
+        final_pred = str(np.round(contrib_df.contribution.sum(), round))
+
+    contrib_summary_df = contrib_summary_df.append(
+            dict(Reason="Final prediction", Effect=final_pred), ignore_index=True)
+    
     return contrib_summary_df.reset_index(drop=True)
 
 
@@ -654,24 +663,37 @@ def decisiontree_df_summary(decisiontree_df, classifier=False, round=2):
                                 + decisiontree_df.iloc[[-1]]['diff'].item(), round)
 
 
-    decisiontree_summary_df = pd.DataFrame(columns=['value', 'condition', 'change', 'prediction'])
+    decisiontree_summary_df = pd.DataFrame(columns=['Feature', 'Condition', 'Adjustment', 'New Prediction'])
+    decisiontree_summary_df = decisiontree_summary_df.append({
+                            'Feature' : "",
+                            'Condition' : "",
+                            'Adjustment' : "Starting average",
+                            'New Prediction' : str(np.round(base_value, round)) + '%'
+                        }, ignore_index=True)
 
     for _, row in decisiontree_df.iterrows():
         if classifier:
             decisiontree_summary_df = decisiontree_summary_df.append({
-                            'value' : (str(row['feature'])+'='+str(row['value'])).ljust(50),
-                            'condition' : str('>=' if row['direction'] == 'right' else '< ') + str(row['split']).ljust(10),
-                            'change' : str('+' if row['diff'] >= 0 else '') + str(np.round(100*row['diff'], round)) +'%',
-                            'prediction' : str(np.round(100*(row['average']+row['diff']), round)) + '%'
+                            'Feature' : row['feature'],
+                            'Condition' : str(row['value']) + str(' >= ' if row['direction'] == 'right' else ' < ') + str(row['split']).ljust(10),
+                            'Adjustment' : str('+' if row['diff'] >= 0 else '') + str(np.round(100*row['diff'], round)) +'%',
+                            'New Prediction' : str(np.round(100*(row['average']+row['diff']), round)) + '%'
                         }, ignore_index=True)
         else:
             decisiontree_summary_df = decisiontree_summary_df.append({
-                            'value' : (str(row['feature'])+'='+str(row['value'])).ljust(50),
-                            'condition' : str('>=' if row['direction'] == 'right' else '< ') + str(row['split']).ljust(10),
-                            'change' : str('+' if row['diff'] >= 0 else '') + str(np.round(row['diff'], round)),
-                            'prediction' : str(np.round((row['average']+row['diff']), round))
+                            'Feature' : row['feature'],
+                            'Condition' : str(row['value']) + str(' >= ' if row['direction'] == 'right' else ' < ') + str(row['split']).ljust(10),
+                            'Adjustment' : str('+' if row['diff'] >= 0 else '') + str(np.round(row['diff'], round)),
+                            'New Prediction' : str(np.round((row['average']+row['diff']), round))
                         }, ignore_index=True)
 
-    return base_value, prediction, decisiontree_summary_df
+    decisiontree_summary_df = decisiontree_summary_df.append({
+                        'Feature' : "",
+                        'Condition' : "",
+                        'Adjustment' : "Final Prediction",
+                        'New Prediction' : str(np.round(prediction, round)) + ('%' if classifier else '')
+                    }, ignore_index=True)
+
+    return decisiontree_summary_df
 
     
\ No newline at end of file
